@@ -18,15 +18,19 @@ use futures::Future;
 use rand::{self, distributions::Alphanumeric, rngs::OsRng, Rng};
 use std::time::Duration;
 
-pub(crate) fn retry<R, E, Fn, Fut>(op: Fn) -> impl Future<Output = Result<R, E>>
+pub(crate) fn retry<R, E, Fn, Fut>(
+    op: Fn,
+    initial_interval: Duration,
+    max_elapsed_time: Duration,
+) -> impl Future<Output = Result<R, E>>
 where
     Fn: FnMut() -> Fut,
     Fut: Future<Output = Result<R, backoff::Error<E>>>,
 {
     let backoff = ExponentialBackoff {
-        initial_interval: Duration::from_millis(500),
-        max_interval: Duration::from_secs(15),
-        max_elapsed_time: Some(Duration::from_secs(180)),
+        initial_interval,
+        max_interval: max_elapsed_time,
+        max_elapsed_time: Some(max_elapsed_time),
         ..Default::default()
     };
 
